@@ -121,7 +121,7 @@ def get_composite_report(delta, ret, long_short_split=True):
         return pd.concat([report_all, report_long, report_short, report_sub])
 
 
-def get_pnl_plot(delta, ret, fig_return=False, alpha=False, **kwargs):
+def get_pnl_plot(delta, ret, fig_return=False, alpha=True, **kwargs):
     """
     delta: pd.Series with DatatimeIndex
     ret: pd.Series with DatatimeIndex
@@ -176,7 +176,7 @@ def get_pnl_plot(delta, ret, fig_return=False, alpha=False, **kwargs):
     day_ret.cumsum().plot(ax=ax1, ls=':', c='k', alpha=0.5, label='Asset')
 
     if alpha:
-        print('Alpha Report: \n', _get_report2(day_pnl - day_ret))
+        print(_get_report2(day_pnl - day_ret).rename('Alpha Report').to_frame().T)
         (day_pnl.cumsum() - day_ret.cumsum()).plot(ax=ax1, label='Alpha', ls='--', c='y')
 
     ax1.set_title('PnL={} PoT={} Sharpe={} Calmar={} WR={:.2f} HP={:.2f}'.format(
@@ -319,7 +319,7 @@ def get_composite_pnl_plot(delta, ret, fig_return=False, alpha=True, **kwargs):
     day_pnl_short.cumsum().plot(ax=ax1, label='Only Short', c='g', ls='--')
     day_ret.cumsum().plot(ax=ax1, ls=':', c='k', alpha=0.5, label='Asset')
     if alpha:
-        print('Alpha Report: \n', _get_report_composite2(day_pnl - day_ret))
+        print(_get_report_composite2(pnl - (indicator_og * ret).sum(axis=1)).rename('Alpha Report').to_frame().T)
         (day_pnl.cumsum() - day_ret.cumsum()).plot(ax=ax1, label='Alpha', ls='--', c='y')
 
     report_all = _get_report_composite(indicator, ret)
